Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/otg_mcp/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/__main__.py | (no class) | 9 | 9 | 20 | 2 | 0 | 0%
src/otg_mcp/client.py | OtgClient | 649 | 441 | 0 | 178 | 11 | 29%
src/otg_mcp/client.py | (no class) | 54 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/client_capture.py | (no class) | 90 | 82 | 0 | 10 | 0 | 8%
src/otg_mcp/config.py | LoggingConfig | 7 | 0 | 0 | 2 | 0 | 100%
src/otg_mcp/config.py | PortConfig | 9 | 5 | 0 | 8 | 2 | 35%
src/otg_mcp/config.py | TargetConfig | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/config.py | TargetsConfig | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/config.py | SchemaConfig | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/config.py | Config | 88 | 79 | 0 | 20 | 2 | 10%
src/otg_mcp/config.py | (no class) | 31 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/__init__.py | (no class) | 2 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | ApiResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | ConfigResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | MetricsResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | CaptureResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | ControlResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | PortInfo | 1 | 1 | 0 | 0 | 0 | 0%
src/otg_mcp/models/models.py | CapabilitiesVersionResponse | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | TrafficGeneratorInfo | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | TrafficGeneratorStatus | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | TargetHealthInfo | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | HealthStatus | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | SnappiError | 0 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/models/models.py | (no class) | 47 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/schema_registry.py | SchemaRegistry | 202 | 3 | 0 | 66 | 0 | 99%
src/otg_mcp/schema_registry.py | (no class) | 18 | 0 | 0 | 0 | 0 | 100%
src/otg_mcp/server.py | OtgMcpServer | 67 | 67 | 0 | 8 | 0 | 0%
src/otg_mcp/server.py | (no class) | 44 | 14 | 2 | 0 | 0 | 68%
Total |  | 1318 | 701 | 22 | 294 | 15 | 45%

No items found using the specified filter.